@@ -32,7 +32,6 @@ import org.apache.hadoop.mapreduce.lib.input.MultipleInputs;
 import org.apache.hadoop.mapreduce.lib.input.SequenceFileInputFormat;
 import org.apache.hadoop.mapreduce.lib.output.FileOutputFormat;
 import org.apache.hadoop.mapreduce.lib.output.MapFileOutputFormat;
-import org.apache.hadoop.util.StringUtils;
 import org.apache.hadoop.util.Tool;
 import org.apache.hadoop.util.ToolRunner;
 
@@ -158,7 +157,7 @@ public class Injector extends NutchTool implements Tool {
           if (filters != null)
             url = filters.filter(url); // filter the url
         } catch (Exception e) {
-          LOG.warn("Skipping " + url + ":" + e);
+          LOG.warn("Skipping {}: {}", url, e);
           url = null;
         }
       }
@@ -200,8 +199,8 @@ public class Injector extends NutchTool implements Tool {
             datum.getMetaData().put(new Text(metaname), new Text(metavalue));
           }
         } catch (NumberFormatException nfe) {
-          LOG.error("Invalid number '" + metavalue + "' in metadata '"
-              + metaname + "' for url " + url);
+          LOG.error("Invalid number '{}' in metadata '{}' for url {}",
+              metavalue, metaname, url);
         }
       }
     }
@@ -285,8 +284,8 @@ public class Injector extends NutchTool implements Tool {
       scoreInjected = conf.getFloat("db.score.injected", 1.0f);
       overwrite = conf.getBoolean("db.injector.overwrite", false);
       update = conf.getBoolean("db.injector.update", false);
-      LOG.info("Injector: overwrite: " + overwrite);
-      LOG.info("Injector: update: " + update);
+      LOG.info("Injector: overwrite: {}", overwrite);
+      LOG.info("Injector: update: {}", update);
     }
 
     /**
@@ -358,6 +357,39 @@ public class Injector extends NutchTool implements Tool {
     setConf(conf);
   }
 
+  private Job prepareJob(Configuration conf, Path urlDir, Path current, Path tempCrawlDb) throws IOException {
+    Job job = Job.getInstance(conf, "Nutch Injector: " + urlDir);
+    job.setJarByClass(Injector.class);
+    job.setMapperClass(InjectMapper.class);
+    job.setReducerClass(InjectReducer.class);
+    job.setOutputFormatClass(MapFileOutputFormat.class);
+    job.setOutputKeyClass(Text.class);
+    job.setOutputValueClass(CrawlDatum.class);
+    job.setSpeculativeExecution(false);
+
+    // set input and output paths of the job
+    MultipleInputs.addInputPath(job, current, SequenceFileInputFormat.class);
+    FileStatus[] seedFiles = urlDir.getFileSystem(conf).listStatus(urlDir);
+    int numSeedFiles = 0;
+    for (FileStatus seedFile : seedFiles) {
+      if (seedFile.isFile()) {
+        MultipleInputs.addInputPath(job, seedFile.getPath(),
+            KeyValueTextInputFormat.class);
+        numSeedFiles++;
+        LOG.info("Injecting seed URL file {}", seedFile.getPath());
+      } else {
+        LOG.warn("Skipped non-file input in {}: {}", urlDir,
+            seedFile.getPath());
+      }
+    }
+    if (numSeedFiles == 0) {
+      LOG.error("No seed files to inject found in {}", urlDir);
+      throw new IllegalStateException("No seed files found");
+    }
+    FileOutputFormat.setOutputPath(job, tempCrawlDb);
+    return job;
+  }
+
   public void inject(Path crawlDb, Path urlDir)
       throws IOException, ClassNotFoundException, InterruptedException {
     inject(crawlDb, urlDir, false, false);
@@ -400,41 +432,12 @@ public class Injector extends NutchTool implements Tool {
     Path tempCrawlDb = new Path(crawlDb,
         "crawldb-" + Integer.toString(new Random().nextInt(Integer.MAX_VALUE)));
 
+    // configure job
+    Job job = prepareJob(conf, urlDir, current, tempCrawlDb);
+
     // lock an existing crawldb to prevent multiple simultaneous updates
     Path lock = CrawlDb.lock(conf, crawlDb, false);
 
-    // configure job
-    Job job = Job.getInstance(conf, "Nutch Injector: " + urlDir);
-    job.setJarByClass(Injector.class);
-    job.setMapperClass(InjectMapper.class);
-    job.setReducerClass(InjectReducer.class);
-    job.setOutputFormatClass(MapFileOutputFormat.class);
-    job.setOutputKeyClass(Text.class);
-    job.setOutputValueClass(CrawlDatum.class);
-    job.setSpeculativeExecution(false);
-
-    // set input and output paths of the job
-    MultipleInputs.addInputPath(job, current, SequenceFileInputFormat.class);
-    FileStatus[] seedFiles = urlDir.getFileSystem(getConf()).listStatus(urlDir);
-    int numSeedFiles = 0;
-    for (FileStatus seedFile : seedFiles) {
-      if (seedFile.isFile()) {
-        MultipleInputs.addInputPath(job, seedFile.getPath(),
-            KeyValueTextInputFormat.class);
-        numSeedFiles++;
-        LOG.info("Injecting seed URL file {}", seedFile.getPath());
-      } else {
-        LOG.warn("Skipped non-file input in {}: {}", urlDir,
-            seedFile.getPath());
-      }
-    }
-    if (numSeedFiles == 0) {
-      LOG.error("No seed files to inject found in {}", urlDir);
-      LockUtil.removeLockFile(fs, lock);
-      return;
-    }
-    FileOutputFormat.setOutputPath(job, tempCrawlDb);
-
     try {
       // run the job
       boolean success = job.waitForCompletion(true);
@@ -487,6 +490,8 @@ public class Injector extends NutchTool implements Tool {
       LOG.error("Injector job failed: {}", e.getMessage());
       NutchJob.cleanupAfterFailure(tempCrawlDb, lock, fs);
       throw e;
+    } finally {
+      LockUtil.removeLockFile(fs, lock);
     }
   }
 
@@ -575,7 +580,7 @@ public class Injector extends NutchTool implements Tool {
           filter, filterNormalizeAll);
       return 0;
     } catch (Exception e) {
-      LOG.error("Injector: " + StringUtils.stringifyException(e));
+      LOG.error("Injector:", e);
       return -1;
     }
   }
