@@ -309,11 +309,9 @@ public class FetcherThread extends Thread {
           }
           
           do {
-            if (LOG.isInfoEnabled()) {
-              LOG.info("{} {} fetching {} (queue crawl delay={}ms)", getName(),
-                  Thread.currentThread().getId(), fit.url,
-                  fetchQueues.getFetchItemQueue(fit.queueID).crawlDelay);
-            }
+            LOG.info("{} {} fetching {} (queue crawl delay={}ms)", getName(),
+                Thread.currentThread().getId(), fit.url,
+                fetchQueues.getFetchItemQueue(fit.queueID).crawlDelay);
             LOG.debug("redirectCount={}", redirectCount);
             redirecting = false;
             Protocol protocol = this.protocolFactory.getProtocol(fit.u);
@@ -375,7 +373,7 @@ public class FetcherThread extends Thread {
                 }
                 fiq.crawlDelay = crawlDelay;
                 LOG.debug(
-                    "Crawl delay for queue: {} is set to {} as per robots.txt. url: ",
+                    "Crawl delay for queue: {} is set to {} as per robots.txt. url: {}",
                     fit.queueID, fiq.crawlDelay, fit.url);
               }
             }
@@ -404,11 +402,6 @@ public class FetcherThread extends Thread {
 
             switch (status.getCode()) {
 
-            case ProtocolStatus.WOULDBLOCK:
-              // retry ?
-              fetchQueues.addFetchItem(fit);
-              break;
-
             case ProtocolStatus.SUCCESS: // got a page
               pstatus = output(fit.url, fit.datum, content, status,
                   CrawlDatum.STATUS_FETCH_SUCCESS, fit.outlinkDepth);
@@ -457,8 +450,8 @@ public class FetcherThread extends Thread {
                 context.getCounter("FetcherStatus",
                     "AboveExceptionThresholdInQueue").increment(killedURLs);
               /* FALLTHROUGH */
+
             case ProtocolStatus.RETRY: // retry
-            case ProtocolStatus.BLOCKED:
               output(fit.url, fit.datum, null, status,
                   CrawlDatum.STATUS_FETCH_RETRY);
               break;
@@ -477,10 +470,8 @@ public class FetcherThread extends Thread {
               break;
 
             default:
-              if (LOG.isWarnEnabled()) {
-                LOG.warn("{} {} Unknown ProtocolStatus: {}", getName(),
-                    Thread.currentThread().getId(), status.getCode());
-              }
+              LOG.warn("{} {} Unknown ProtocolStatus: {}", getName(),
+                  Thread.currentThread().getId(), status.getCode());
               output(fit.url, fit.datum, null, status,
                   CrawlDatum.STATUS_FETCH_RETRY);
             }
@@ -489,11 +480,9 @@ public class FetcherThread extends Thread {
               fetchQueues.finishFetchItem(fit);
               context.getCounter("FetcherStatus", "redirect_count_exceeded")
                   .increment(1);
-              if (LOG.isInfoEnabled()) {
-                LOG.info("{} {} - redirect count exceeded {} ({})", getName(),
-                    Thread.currentThread().getId(), fit.url,
-                    maxRedirectExceededSkip ? "skipped" : "linked");
-              }
+              LOG.info("{} {} - redirect count exceeded {} ({})", getName(),
+                  Thread.currentThread().getId(), fit.url,
+                  maxRedirectExceededSkip ? "skipped" : "linked");
               if (maxRedirectExceededSkip) {
                 // skip redirect target when redirect count is exceeded
               } else {
@@ -524,9 +513,7 @@ public class FetcherThread extends Thread {
       }
 
     } catch (Throwable e) {
-      if (LOG.isErrorEnabled()) {
-        LOG.error("fetcher caught:", e);
-      }
+      LOG.error("fetcher caught:", e);
     } finally {
       if (fit != null) {
         fetchQueues.finishFetchItem(fit);
@@ -651,10 +638,8 @@ public class FetcherThread extends Thread {
   }
 
   private void logError(Text url, String message) {
-    if (LOG.isInfoEnabled()) {
-      LOG.info("{} {} fetch of {} failed with: {}", getName(),
-          Thread.currentThread().getId(), url, message);
-    }
+    LOG.info("{} {} fetch of {} failed with: {}", getName(),
+        Thread.currentThread().getId(), url, message);
     errors.incrementAndGet();
   }
 
@@ -686,10 +671,8 @@ public class FetcherThread extends Thread {
       try {
         scfilters.passScoreBeforeParsing(key, datum, content);
       } catch (Exception e) {
-        if (LOG.isWarnEnabled()) {
-          LOG.warn("{} {} Couldn't pass score, url {} ({})", getName(),
-              Thread.currentThread().getId(), key, e);
-        }
+        LOG.warn("{} {} Couldn't pass score, url {} ({})", getName(),
+            Thread.currentThread().getId(), key, e);
       }
 
       if (status == CrawlDatum.STATUS_FETCH_SUCCESS) {
@@ -751,10 +734,8 @@ public class FetcherThread extends Thread {
           try {
             scfilters.passScoreAfterParsing(url, content, parse);
           } catch (Exception e) {
-            if (LOG.isWarnEnabled()) {
-              LOG.warn("{} {} Couldn't pass score, url {} ({})", getName(),
-                  Thread.currentThread().getId(), key, e);
-            }
+            LOG.warn("{} {} Couldn't pass score, url {} ({})", getName(),
+                Thread.currentThread().getId(), key, e);
           }
 
           String origin = null;
@@ -875,9 +856,7 @@ public class FetcherThread extends Thread {
         }
       }
     } catch (IOException e) {
-      if (LOG.isErrorEnabled()) {
-        LOG.error("fetcher caught:", e);
-      }
+      LOG.error("fetcher caught:", e);
     }
 
     // return parse status (of the "original" URL if the ParseResult contains
@@ -895,13 +874,13 @@ public class FetcherThread extends Thread {
   
   private void outputRobotsTxt(List<Content> robotsTxtContent) throws InterruptedException {
     for (Content robotsTxt : robotsTxtContent) {
-      LOG.debug("fetched and stored robots.txt {}",
+      LOG.debug("Fetched and stored robots.txt {}",
           robotsTxt.getUrl());
       try {
         context.write(new Text(robotsTxt.getUrl()),
             new NutchWritable(robotsTxt));
       } catch (IOException e) {
-        LOG.error("fetcher caught:", e);
+        LOG.error("Fetcher failed to store the robots.txt:", e);
       }
     }
   }
